/**
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof assert>} Assert
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof location>} AssertLocation
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof inclusion>} AssertInclusion
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof partition>} AssertPartition
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof relation>} AssertRelation
 */
export const assert: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/*", import("@ucanto/interface").URI<"did:">, {}>>;
/**
 * Claim that a CID is available at a URL.
 */
export const location: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/location", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    location: Schema.ArraySchema<import("@ucanto/interface").URI<`${string}:`>, unknown>;
    range: Schema.Schema<Schema.InferStruct<{
        offset: Schema.NumberSchema<number & import("@ucanto/server").Phantom<{
            typeof: "integer";
        }>, unknown>;
        length: Schema.Schema<(number & import("@ucanto/server").Phantom<{
            typeof: "integer";
        }>) | undefined, unknown>;
    }> | undefined, unknown>;
}>>>;
/**
 * Claim that within a CAR, there are a bunch of CIDs (and their offsets).
 */
export const inclusion: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/inclusion", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    includes: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
    proof: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1> | undefined, any>;
}>>>;
/**
 * Claims that a DAG can be found in a bunch of CAR files.
 */
export const partition: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/partition", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    blocks: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1> | undefined, any>;
    parts: Schema.ArraySchema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
}>>>;
/**
 * Claim that a block links to other block(s). Similar to a partition claim
 * a relation claim asserts that a block of content links to other blocks and
 * that the block and it's links may be found in the specified parts.
 */
export const relation: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/relation", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    children: Schema.ArraySchema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
    parts: Schema.ArraySchema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
}>>>;
export type Assert = import('@ucanto/server').InferInvokedCapability<typeof assert>;
export type AssertLocation = import('@ucanto/server').InferInvokedCapability<typeof location>;
export type AssertInclusion = import('@ucanto/server').InferInvokedCapability<typeof inclusion>;
export type AssertPartition = import('@ucanto/server').InferInvokedCapability<typeof partition>;
export type AssertRelation = import('@ucanto/server').InferInvokedCapability<typeof relation>;
import { Link } from '@ucanto/server';
import { Schema } from '@ucanto/server';
//# sourceMappingURL=assert.d.ts.map